OiRA

Help

1. Presentazione
2. Processo di VR
3. Identificazione + Valutazione
   1. 1 Commercial manned guarding
   2. Ω Rischi aggiuntivi
      1. Ω.1 The entrance floor is often wet
   - Non esaminato
   - Adempimenti e rischi da completare
   - Adempimenti e rischi non applicabili o per i quali non sono previste ulteriori misure di miglioramento
   - Adempimenti e rischi per i quali sono previste ulteriori misure di miglioramento
4. Misure di miglioramento
5. Report
6. Stato 0%

Qualora siano stati identificati rischi non inclusi in questo strumento, è possibile aggiungerli ora:

I criteri adottati per la valutazione devono essere riportati nel documento di valutazione dei rischi ai sensi del art. 28, c. 2 a, d.lgs. 81/08. A tal fine i criteri possono essere indicati nel campo note presente sotto la sezione commenti in ogni specifico rischio aggiunto.
Per ogni rischio aggiunto inoltre, nella sezione informazioni è possibile inserire eventuali note e immagini utilizzate per identificare il pericolo e per la valutazione del relativo rischio. Tali informazioni non sono visualizzate nel report.

Importante: Per evitare la duplicazione dei rischi, raccomandiamo di ripassare in esame tutti i moduli precedenti, qualora tale operazione non sia ancora stata compiuta.

Indietro Vai alla sezione misure di miglioramento

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More